pub struct LazyRotation { /* private fields */ }Trait Implementations
Sourceimpl Clone for LazyRotation
impl Clone for LazyRotation
Sourceimpl Mul<LazyRotation> for &Frame
Creates a new derived frame rotated by rhs about the axes of self
(local frame, matching the Pose operator semantics).
impl Mul<LazyRotation> for &Frame
Creates a new derived frame rotated by rhs about the axes of self
(local frame, matching the Pose operator semantics).
The derived frame resolves transforms through self but is not stored in the tree:
it does not appear in children() or serialization, is read-only, and is freed when
dropped.