pub struct LazyTranslation { /* private fields */ }Trait Implementations
Sourceimpl Add<LazyTranslation> for &Frame
Creates a new derived frame translated by rhs, interpreted in the
parent frame of self (matching the Pose operator semantics).
impl Add<LazyTranslation> for &Frame
Creates a new derived frame translated by rhs, interpreted in the
parent frame of self (matching the Pose operator semantics).
The derived frame resolves transforms through self but is not stored in the tree:
it does not appear in children() or serialization, is read-only, and is freed when
dropped.
Sourceimpl Add<LazyTranslation> for &Pose
impl Add<LazyTranslation> for &Pose
Sourceimpl Clone for LazyTranslation
impl Clone for LazyTranslation
Sourceimpl Sub<LazyTranslation> for &Frame
Creates a new derived frame translated by the inverse of rhs, interpreted
in the parent frame of self (matching the Pose operator semantics).
impl Sub<LazyTranslation> for &Frame
Creates a new derived frame translated by the inverse of rhs, interpreted
in the parent frame of self (matching the Pose operator semantics).
The derived frame resolves transforms through self but is not stored in the tree:
it does not appear in children() or serialization, is read-only, and is freed when
dropped.