Module tree
cartesian_
tree
0.1.0
Module tree
Module Items
Structs
In crate cartesian_
tree
cartesian_tree
Module
tree
Cartesian Tree
Structs

Cartesian
Tree
A cartesian tree is a heap ordered binary tree derived from some underlying array. An in-order traversal of the tree yields the underlying array.